@@ -89,6 +89,11 @@ void HMAC::set(const char *digest, const char *key, size_t len)
         gnutls_hmac_init((HMAC_CTX *)&context, id, key, len);
 }
 
+void HMAC::set(const char *digest, const secure::keybytes& key)
+{
+    set(digest, (const char *)*key, key.size() / 8);
+}
+
 bool HMAC::has(const char *type)
 {
     HMAC_ID id = (HMAC_ID)__context::map_hmac(type);
