@@ -60,13 +60,13 @@ namespace Type {
     class SecChars 
     {
     public:
-        typedef enum {GENERIC_STRING, B64_STRING, HEX_STRING, MD5_DIGEST, SHA_DIGEST} strtype_t;  
+        typedef enum {GENERIC_STRING, B64_STRING, HEX_STRING, MD5_DIGEST, SHA_DIGEST, PEM_PUBLIC, PEM_PRIVATE} strtype_t;  
     };
 
     class KeyBytes
     {
     public:
-        typedef enum {UNDEFINED_KEYTYPE, IV_BUFFER, UNPAIRED_KEYTYPE, RSA_KEYTYPE} keytype_t;
+        typedef enum {UNDEFINED_KEYTYPE, IV_BUFFER, UNPAIRED_KEYTYPE, RSA_KEYTYPE, KEY_DIGEST} keytype_t;
     };
 
 }
@@ -136,11 +136,11 @@ public:
 
     void hex(const uint8_t *bytes, size_t bsize);
 
-    strtype_t type(void);
+    strtype_t type(void) const;
 
-    size_t size(void);
+    size_t size(void) const;
 
-    size_t len(void);
+    size_t len(void) const;
 };
 
 template <>
@@ -192,9 +192,11 @@ public:
 
     void generate(size_t keysize, keytype_t keytype = UNPAIRED_KEYTYPE);
 
-    keytype_t type(void);
+    keytype_t type(void) const;
 
-    size_t size(void);
+    size_t size(void) const;
+
+    size_t bytes(void) const;
 };
 
 template<>
@@ -494,13 +496,13 @@ public:
 
         void set(const unsigned char *key, size_t size);
 
-        bool set(secure::keybytes& key);
+        bool set(const secure::keybytes& key);
 
         void set(const char *cipher, const char *digest);
 
         void set(const char *cipher, const uint8_t *iv, size_t ivsize);
 
-        bool set(const char *cipher, secure::keybytes& iv);
+        bool set(const char *cipher, const secure::keybytes& iv);
 
         void assign(const char *key, size_t size, const unsigned char *salt, unsigned rounds);
 
@@ -742,6 +744,17 @@ public:
     static secure::string sha1(const char *text);
 
     static secure::string sha256(const char *text);
+
+    static secure::string sha384(const char *text);
+
+    static secure::keybytes md5(const uint8_t *mem, size_t size);
+
+    static secure::keybytes sha1(const uint8_t *mem, size_t size);
+
+    static secure::keybytes sha256(const uint8_t *mem, size_t size);
+
+    static secure::keybytes sha384(const uint8_t *mem, size_t size);
+
 };
 
 /**
@@ -770,6 +783,8 @@ protected:
 public:
     HMAC(const char *digest, const char *key, size_t keylen = 0);
 
+    HMAC(const char *digest, const secure::keybytes& key);
+
     HMAC();
 
     ~HMAC();
@@ -806,6 +821,8 @@ public:
 
     void set(const char *digest, const char *key, size_t len);
 
+    void set(const char *digest, const secure::keybytes& key);
+
     inline bool operator *=(const char *text)
         {return puts(text);}
 
@@ -827,6 +844,25 @@ public:
      * @return true if supported, false if not.
      */
     static bool has(const char *name);
+
+    static secure::keybytes sha256(secure::keybytes key, const uint8_t *mem, size_t size);
+
+    static secure::keybytes sha384(secure::keybytes key, const uint8_t *mem, size_t soze);
+};
+
+class __SHARED RSA
+{
+private:
+    void *keypair;
+
+    __DELETE_COPY(RSA);
+
+public:
+    RSA(secure::string privkey, secure::string pubkey); // pem
+    RSA(size_t keysize);
+    ~RSA();
+
+    secure::string pem(secure::strtype_t type);
 };
 
 /**
